# User Guide

```{toctree}
installation
chopper/index
coordinate-transformations
groupby
from-mantid-to-scipp
instrument-view
recipes
masking-tool
wfm/index
algorithms-background/index
absorption-correction
```
